@@ -12,7 +12,6 @@ from scipy import sparse
 import matplotlib
 matplotlib.use('agg')
 from tadlib.hitad.aligner import BoundSet, DomainSet, DomainAligner, hierFormat, Container
-from tadlib.calfea import analyze
 from matplotlib.colors import Normalize
 
 class MidpointNormalize(Normalize):
@@ -834,10 +833,6 @@ class Chrom(object):
         tadlib.hitad.chromLev.Chrom.idxmatch : Pair intra-domain and inter-domain
                                                interactions with the same
                                                genomic distance
-        tadlib.calfea.analyze.Core.longrange : Assign the weight value for each
-                                               intra-domain interaction according
-                                               to the genomic distance and
-                                               the local interaction background.
         """
         ori = domain[0] // self.res + self.chromLen
         end = domain[1] // self.res + self.chromLen
@@ -860,27 +855,6 @@ class Chrom(object):
         inout = 0
         if inside.size > 3:
             weights = 0.5
-            '''
-            if len(bases):
-                M = self.getSelfMatrix(domain[0], domain[1])
-                newM, convert = analyze.manipulation(M)
-                if newM.shape[0] > 10: # 2*ww + 1
-                    work = analyze.Core(M)
-                    work.longrange(pw=1, ww=3)
-                    fE = work.convertMatrix(work.fE)
-                    for d in bases:
-                        ds = (d[0]-domain[0])//self.res
-                        de = (d[1]-domain[0])//self.res
-                        fE[ds:de,ds:de] = 0
-                    pkv = fE[fE>0]
-                    if pkv.size > 0:
-                        norm = MidpointNormalize(vmin=np.percentile(pkv,1),
-                                                 vmax=np.percentile(pkv,99),
-                                                 midpoint=1)
-                        W = norm(fE).data
-                        W[fE==0] = 0.5
-                        weights = np.r_[W[Umask], W[Dmask]]
-            '''
             diff = (inside - outside) / (inside + outside) * weights
             inout = diff.mean()
 
@@ -1160,24 +1134,7 @@ class Chrom(object):
         """
         M = self.getSelfMatrix(start, end)
         W = np.ones(M.shape) * 0.5
-        '''
-        newM, convert = analyze.manipulation(M)
-        if newM.shape[0] > 7: # 2*ww + 1
-            work = analyze.Core(M)
-            work.longrange(pw=1, ww=3)
-            fE = work.convertMatrix(work.fE)
-            for d in bases:
-                ds = (d[0]-start)//self.res
-                de = (d[1]-start)//self.res
-                fE[ds:de,ds:de] = 0
-            pkv = fE[fE>0]
-            if pkv.size > 0:
-                norm = MidpointNormalize(vmin=np.percentile(pkv,1),
-                                         vmax=np.percentile(pkv,99),
-                                         midpoint=1)
-                W = norm(fE).data
-                W[fE==0] = 0.5
-        '''
+        
         return W
         
 
